==> lxqt-globalkeys_0.17.0.orig.tar.xz: lxqt-globalkeys-0.17.0/config/translations/lxqt-config-globalkeyshortcuts_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation>DBus volání</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation>Identif.</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Informace</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Upravit akci</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>Kláve&amp;sová zkratka:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Popis:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>Povol&amp;eno</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Příkaz</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Zpráva z &amp;DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Přík&amp;az:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>&amp;Služba:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Popis umístění:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Rozhraní:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Metoda:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globální správa akcí</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="55"/>
        <source>Add ...</source>
        <translation>Přidat…</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="65"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="75"/>
        <source>Modify ...</source>
        <translation>Změnit…</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Swap</source>
        <translation>Prohodit</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="118"/>
        <source>Multiple actions behaviour:</source>
        <translation>Chování při více akcích:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="126"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>První</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="131"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Poslední</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="136"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Žádná</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="141"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Vše</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="166"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="186"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="187"/>
        <source>Restore Default</source>
        <translation>Vrátit na výchozí hodnoty</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="188"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Vámi určené klávesové zkratky budou odebrány.
Opravdu to chcete?</translation>
    </message>
</context>
</TS>

==> lxqt-globalkeys_2.1.0.orig.tar.xz: lxqt-globalkeys-2.1.0/config/translations/lxqt-config-globalkeyshortcuts_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Command</source>
        <translation>Příkaz</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="52"/>
        <source>DBus call</source>
        <translation>DBus volání</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="53"/>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="143"/>
        <source>Id</source>
        <translation>Identif.</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="146"/>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="149"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="152"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="155"/>
        <source>Info</source>
        <translation>Informace</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Upravit akci</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>Kláve&amp;sová zkratka:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Popis:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>Povol&amp;eno</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Příkaz</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Zpráva z &amp;DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Přík&amp;az:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>&amp;Služba:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Popis umístění:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Rozhraní:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Metoda:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Globální správa akcí</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="27"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="72"/>
        <source>Add ...</source>
        <translation>Přidat…</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="82"/>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Modify ...</source>
        <translation>Změnit…</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="109"/>
        <source>Swap</source>
        <translation>Prohodit</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="135"/>
        <source>Multiple actions behaviour:</source>
        <translation>Chování při více akcích:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="143"/>
        <source>First</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>První</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="148"/>
        <source>Last</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Poslední</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="153"/>
        <source>None</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Žádná</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="158"/>
        <source>All</source>
        <comment>globalkeys/config/multipleActions</comment>
        <translation>Vše</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="183"/>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="207"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="191"/>
        <source>Restore Default</source>
        <translation>Vrátit na výchozí hodnoty</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="192"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Vámi určené klávesové zkratky budou odebrány.
Opravdu to chcete?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Platform Unsupported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>LXQt globalkeys are currently unsupported under Wayland.

Global shortcuts can be configured in the settings of the compositor instead.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
